pub struct PerfettoProfileChunk { /* private fields */ }Expand description
A parsed Perfetto profiling chunk.
Implementations
Sourceimpl Chunk
impl Chunk
Sourcepub fn parse(sample: &[u8], perfetto: Bytes) -> Result<Self, ProfileError>
pub fn parse(sample: &[u8], perfetto: Bytes) -> Result<Self, ProfileError>
Parses a Chunk from the required v2::ProfileChunk and a Perfetto profile.
A Perfetto profile always requires an associated v2::ProfileChunk for additional
metadata. The resulting Chunk contains all metadata from the v2::ProfileChunk
and samples from the perfetto profile.
Note: if the parsed sample already contains profiling information, the frames in the
Perfetto profile are not extracted again.
Sourcepub fn as_v2(&self) -> &V2ProfileChunk
pub fn as_v2(&self) -> &V2ProfileChunk
Returns the combined metadata and Perfetto profile as a V2ProfileChunk.