V2ProfileChunk

Struct V2ProfileChunk 

pub struct V2ProfileChunk {
    pub measurements: BTreeMap<String, ChunkMeasurement>,
    pub metadata: ProfileMetadata,
    pub profile: ProfileData,
}

Fields

measurements: BTreeMap<String, ChunkMeasurement>metadata: ProfileMetadata

This struct contains all the metadata related to the chunk but all fields are expected to be at the top-level of the object.

profile: ProfileData

Implementations

Source

impl ProfileChunk

pub fn parse(payload: &[u8]) -> Result<Self, ProfileError>

Parses a ProfileChunk from a JSON payload.

pub fn normalize(&mut self) -> Result<(), ProfileError>

Normalizes the ProfileChunk.

pub fn serialize(&self) -> Result<Bytes, ProfileError>

Serializes the ProfileChunk into its JSON form.