pub struct V2ProfileChunk {
pub measurements: BTreeMap<String, ChunkMeasurement>,
pub metadata: ProfileMetadata,
pub profile: ProfileData,
}Fields
measurements: BTreeMap<String, ChunkMeasurement>metadata: ProfileMetadataThis struct contains all the metadata related to the chunk but all fields are expected to be at the top-level of the object.
profile: ProfileDataImplementations
Sourceimpl ProfileChunk
impl ProfileChunk
Sourcepub fn parse(payload: &[u8]) -> Result<Self, ProfileError>
pub fn parse(payload: &[u8]) -> Result<Self, ProfileError>
Parses a ProfileChunk from a JSON payload.
Sourcepub fn normalize(&mut self) -> Result<(), ProfileError>
pub fn normalize(&mut self) -> Result<(), ProfileError>
Normalizes the ProfileChunk.
Sourcepub fn serialize(&self) -> Result<Bytes, ProfileError>
pub fn serialize(&self) -> Result<Bytes, ProfileError>
Serializes the ProfileChunk into its JSON form.